# Kiowa Platform API 

A package containing shared functions in the platform API. 

## Installation

Install this package by using your private PyPI URL:

```bash
pip install kiowaplatform

## Update Package

- Increase version in setup.py
- python -m build 
- twine upload dist/* 


